==> perspective-8.x-1.1.tar.gz: perspective/src/Plugin/Field/FieldWidget/TextWidget.php <==
<?php

namespace Drupal\perspective\Plugin\Field\FieldWidget;

use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Field\Plugin\Field\FieldWidget\StringTextareaWidget;
use Drupal\Core\Form\FormStateInterface;

/**
 * Plugin implementation of the 'perspective_text' widget.
 *
 * @FieldWidget(
 *   id = "perspective_text",
 *   module = "perspective",
 *   label = @Translation("Text"),
 *   field_types = {
 *     "perspective"
 *   }
 * )
 */
class TextWidget extends StringTextareaWidget {

  /**
   * {@inheritdoc}
   */
  public function formElement(FieldItemListInterface $items, $delta, array $element, array &$form, FormStateInterface $form_state) {
    $value = isset($items[$delta]->value) ? $items[$delta]->value : '';
    $main_widget = parent::formElement($items, $delta, $element, $form, $form_state);

    $element = $main_widget['value'];
    $element['#type'] = 'text_format';
    $element['#default_value'] = $value;
    $element['#format'] = $items[$delta]->format;
    $element['#base_type'] = $main_widget['value']['#type'];
    $element['#element_validate'] = [
      [$this, 'validate']
    ];

    return $element;
  }

  /**
   * Validate the color text field.
   */
  public function validate($element, FormStateInterface $form_state) {
    $value = strip_tags($element['#value']);

    $perspective_data = [
      'comment' => [
        'text' => $value
      ],
      'languages' => ['en'],
      'requestedAttributes' => [
        'TOXICITY' => (object) []
      ]
    ];

    $perspective_data_json = json_encode($perspective_data);

    $config = \Drupal::config('perspective.settings');

    $api_call = curl_init('https://commentanalyzer.googleapis.com/v1alpha1/comments:analyze?key=' . $config->get('perspective.google_api_key'));
    curl_setopt($api_call, CURLOPT_CUSTOMREQUEST, "POST");
    curl_setopt($api_call, CURLOPT_POSTFIELDS, $perspective_data_json);
    curl_setopt($api_call, CURLOPT_RETURNTRANSFER, true);
    curl_setopt($api_call, CURLOPT_HTTPHEADER, array(
      'Content-Type: application/json',
      'Content-Length: ' . strlen($perspective_data_json))
    );

    $perspective_data = json_decode(curl_exec($api_call));
    $toxicity = $perspective_data->attributeScores->TOXICITY->summaryScore->value;

    if ((int) ($toxicity * 100) >= $config->get('perspective.tolerance')) {
      $form_state->setError($element, t($config->get('perspective.error_text')));
    }
  }

}

==> perspective-8.x-1.2.tar.gz: perspective/src/Plugin/Field/FieldWidget/TextWidget.php <==
<?php

namespace Drupal\perspective\Plugin\Field\FieldWidget;

use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Field\Plugin\Field\FieldWidget\StringTextareaWidget;
use Drupal\Core\Form\FormStateInterface;

/**
 * Plugin implementation of the 'perspective_text' widget.
 *
 * @FieldWidget(
 *   id = "perspective_text",
 *   module = "perspective",
 *   label = @Translation("Text"),
 *   field_types = {
 *     "perspective"
 *   }
 * )
 */
class TextWidget extends StringTextareaWidget {

  /**
   * {@inheritdoc}
   */
  public function formElement(FieldItemListInterface $items, $delta, array $element, array &$form, FormStateInterface $form_state) {
    $value = isset($items[$delta]->value) ? $items[$delta]->value : '';
    $main_widget = parent::formElement($items, $delta, $element, $form, $form_state);

    $element = $main_widget['value'];
    $element['#type'] = 'text_format';
    $element['#default_value'] = $value;
    $element['#format'] = $items[$delta]->format;
    $element['#base_type'] = $main_widget['value']['#type'];
    $element['#element_validate'] = [
      [$this, 'validate'],
    ];

    return $element;
  }

  /**
   * Validate the color text field.
   */
  public function validate($element, FormStateInterface $form_state) {
    $value = strip_tags($element['#value']);

    $perspective_data = [
      'comment' => [
        'text' => $value,
      ],
      'languages' => ['en'],
      'requestedAttributes' => [
        'TOXICITY' => (object) [],
      ],
    ];

    $perspective_data_json = json_encode($perspective_data);

    $config = \Drupal::config('perspective.settings');

    $api_call = curl_init('https://commentanalyzer.googleapis.com/v1alpha1/comments:analyze?key=' . $config->get('perspective.google_api_key'));
    curl_setopt($api_call, CURLOPT_CUSTOMREQUEST, "POST");
    curl_setopt($api_call, CURLOPT_POSTFIELDS, $perspective_data_json);
    curl_setopt($api_call, CURLOPT_RETURNTRANSFER, TRUE);
    curl_setopt($api_call, CURLOPT_HTTPHEADER, array(
      'Content-Type: application/json',
      'Content-Length: ' . strlen($perspective_data_json),
    )
    );

    $perspective_data = json_decode(curl_exec($api_call));
    $toxicity = $perspective_data->attributeScores->TOXICITY->summaryScore->value;

    if ((int) ($toxicity * 100) >= $config->get('perspective.tolerance')) {
      $form_state->setError($element, t($config->get('perspective.error_text')));
    }
  }

}
